@@ -6,11 +6,11 @@ from bitmovin_api_sdk.common.poscheck import poscheck_model
 
 
 class AzureCloudRegion(Enum):
-    US_WEST2 = "AUSTRALIA_EAST"
-    US_EAST = "AUSTRALIA_SOUTHEAST"
+    AUSTRALIA_EAST = "AUSTRALIA_EAST"
+    AUSTRALIA_SOUTHEAST = "AUSTRALIA_SOUTHEAST"
     EUROPE_NORTH = "EUROPE_NORTH"
     EUROPE_WEST = "EUROPE_WEST"
     GERMANY_WESTCENTRAL = "GERMANY_WESTCENTRAL"
-    AUSTRALIA_EAST = "UAE_NORTH"
-    AUSTRALIA_SOUTHEAST = "US_EAST"
-    UAE_NORTH = "US_WEST2"
+    UAE_NORTH = "UAE_NORTH"
+    US_EAST = "US_EAST"
+    US_WEST2 = "US_WEST2"
